# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

import os
import re
import sys

import django
import tomli

sys.path.insert(0, os.path.abspath("../heliport"))
os.environ.setdefault("DJANGO_SETTINGS_MODULE", "heliport_config.settings")
django.setup()

with open("../pyproject.toml", "rb") as pyproject_file:
    pyproject = tomli.load(pyproject_file)
poetry_info = pyproject["tool"]["poetry"]

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = "HELIPORT"
author = re.sub(r"<.*>", "", poetry_info["authors"][0]).strip()
copyright = f"2022, {author}"
release = poetry_info["version"]

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    "sphinx.ext.autodoc",
    "myst_parser",
]

templates_path = ["_templates"]
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

source_suffix = {
    ".rst": "restructuredtext",
    ".md": "markdown",
}

myst_enable_extensions = ["colon_fence"]

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = "sphinx_rtd_theme"
html_static_path = ["_static"]
html_favicon = "../heliport/core/static/core/img/favicon.ico"
