<!--
SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf

SPDX-License-Identifier: GPL-3.0-or-later
-->

# Development Setup

Make sure you have Poetry and a Celery Broker installed as described in
[Prerequisites](../administration/prerequisites.rst).

## Create the Environment

Create the python environment with the required packages.
After the `--extras` flag, provide a quoted, space-separated list with all the package
extras you would like to install.
An overview of all available extras can be found in the [Package Overview](
../administration/package-overview.rst).
In this example we're going to install the dependencies for PostgreSQL and LDAP support:

```bash
poetry install --extras "pgsql ldap"
```

Then open a shell with this environment loaded by executing

```bash
poetry shell
```

:::{note}
All of the following commands need to be executed inside the Poetry shell.
:::

Now create a `.env` file by copying the provided sample.

```bash
cd heliport_config
cp -i .env.dist .env
```

Finally, edit the `.env` file to provide your own settings.
Some settings are required, others are commented out and can be left unchanged.
The comments will guide you in the process.
For a development setup of HELIPORT, `DEVELOPMENT` should be uncommented and set to
`True`.

## Run the Tests

To run the tests, execute pytest in the Poetry shell:

```bash
pytest -v
```

## Run the Development Server

To run the server, first do a database migration and then execute the `runserver`
command.

:::{note}
`migrate` is only required when starting the app for the first time or if the database
schema changed since the last start.
:::

```bash
python ./manage.py migrate
python ./manage.py runserver
```

## Start the Celery Worker

Start the Celery worker:

```bash
celery -A heliport_config worker
```

Or run it in the background:

```bash
celery -A heliport_config multi start "celery@$HOSTNAME" --logfile=celery.log --pidfile=celery.pid
```

## Additional Tips

### Admin Interface

If you want an admin for the `/admin/` interface, you can create one:
```bash
python manage.py createsuperuser
```

## Contributing

If you want to contribute code, please make sure to format it by running
[Black](https://black.readthedocs.io/en/stable/) and
[isort](https://pycqa.github.io/isort/):

```bash
black .
isort .
```

Also, please make sure to add a license header to all new files.
`reuse` can help you with this:

```bash
reuse addheader --license GPL-3.0-or-later --copyright "Your institution" --year 2022 path/to/file
```

You can check if the code is up to the [REUSE](https://reuse.software/) spec like this:

```bash
reuse lint
```
