# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.db.models import Q
from rest_framework import permissions

from .models import Project


class HeliportProjectPermission(permissions.BasePermission):
    def has_object_permission(self, request, view, obj):
        if not hasattr(request.user, "heliportuser"):
            return False
        return request.user.heliportuser in obj.members()


class HeliportObjectPermission(permissions.BasePermission):
    def has_object_permission(self, request, view, obj):
        if not hasattr(request.user, "heliportuser"):
            return False
        user = request.user.heliportuser
        return has_permission_for(user, obj)


def has_permission_for(user, obj):
    if user is None:
        return False
    for project in obj.projects.all():
        if user in project.members():
            return True
    return user in obj.members()


def projects_of(heliport_user):
    return Project.objects.filter(
        Q(owner=heliport_user) | Q(co_owners=heliport_user)
    ).distinct()


def is_object_member(heliport_user):
    return Q(projects__owner=heliport_user) | Q(projects__co_owners=heliport_user)


class StaffOrReadOnly(permissions.BasePermission):
    def has_object_permission(self, request, view, obj):
        return request.user.is_staff or request.method in permissions.SAFE_METHODS


def has_read_permission(user, obj):
    return has_permission_for(user, obj)


def has_write_permission(user, obj):
    return has_permission_for(user, obj)
