# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class Unicore(Module):
    name = "UNICORE"
    module_id = "unicore"

    def get_url(self, project):
        return reverse("unicore:overview")

    def is_configured(self, project):
        # TODO: Return true if the currently logged in user has a logininfo called
        #  "UNICORE". We need to know the user for this...
        from .models import UnicoreResource

        resource = UnicoreResource.objects.filter(heliport_project=project).first()
        return resource is not None


class UnicoreProjectJobs(Module):
    name = "UNICORE Jobs"
    module_id = "unicore_project_jobs"

    def get_url(self, project):
        return reverse("unicore:project-jobs", kwargs={"project": project.pk})

    def is_configured(self, project):
        from .models import UnicoreResource

        resource = UnicoreResource.objects.filter(heliport_project=project).first()
        return resource is not None
